# Generated by roxygen2: do not edit by hand

export(check_ilostat_version)
export(clean_ilostat_cache)
export(distribution_ilostat)
export(get_ilostat)
export(get_ilostat_dic)
export(get_ilostat_toc)
export(label_ilostat)
export(runapp_ilostat)
importFrom(data.table,fread)
importFrom(data.table,fwrite)
importFrom(dplyr,"%>%")
importFrom(dplyr,across)
importFrom(dplyr,bind_rows)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,mutate)
importFrom(dplyr,select)
importFrom(dplyr,ungroup)
importFrom(haven,read_dta)
importFrom(haven,read_sas)
importFrom(haven,read_sav)
importFrom(haven,write_dta)
importFrom(haven,write_sas)
importFrom(haven,write_sav)
importFrom(httr2,req_headers)
importFrom(httr2,req_perform)
importFrom(httr2,req_timeout)
importFrom(httr2,request)
importFrom(httr2,resp_body_raw)
importFrom(httr2,resp_status)
importFrom(readr,col_character)
importFrom(readr,col_double)
importFrom(readr,cols)
importFrom(readr,read_csv)
importFrom(readr,read_lines)
importFrom(readr,read_rds)
importFrom(rlang,.data)
importFrom(stats,setNames)
importFrom(stringr,fixed)
importFrom(stringr,str_c)
importFrom(stringr,str_detect)
importFrom(stringr,str_replace)
importFrom(stringr,str_split)
importFrom(stringr,str_sub)
importFrom(tibble,as_tibble)
importFrom(tibble,is_tibble)
importFrom(tidyselect,all_of)
importFrom(tidyselect,contains)
importFrom(tidyselect,where)
importFrom(utils,available.packages)
importFrom(utils,download.file)
importFrom(utils,packageVersion)
